'use strict';

const plugin = require('tailwindcss/plugin');

module.exports = {
  theme: {
    screens: {
      m: { max: '768px' },
      om: { min: '768px' },
      it: { max: '1018px' },
      t: { min: '768px', max: '1018px' },
      ot: { min: '1018px' },
      id: { max: '1358px' },
      d: { min: '1018px', max: '1358px' },
      od: { min: '1358px' },
    },
    extend: {
      width: {
        '240': '240px',
        '320': '320px',
        '360': '360px',
        '480': '480px',
        '512': '512px',
        '640': '640px',
        '720': '720px',
        '90vw': '90vw',
      },
      fontSize: {
        '2xs': '0.625rem',
      },
      fontFamily: {
        kiro: ['Kiro-Regular', 'sans-serif'],
      },
      gridTemplateColumns: {
        '13': '1fr 3fr',
        '23': '2fr 3fr',
        '32': '3fr 2fr',
        a1: 'auto 1fr',
        '1a': '1fr auto',
        aa: 'auto auto',
        '21': '2fr 1fr',
        a1a: 'auto 1fr auto',
        aa1: 'auto auto 1fr',
        '1aa': '1fr auto auto',
        a1aa: 'auto 1fr auto auto',
        '11aa': '1fr 1fr auto auto',
        '1/300px': '1fr 300px',
      },
      gridTemplateRows: {
        '1a': '1fr auto',
        a1: 'auto 1fr',
        a1a: 'auto 1fr auto',
        '1aa': '1fr auto auto',
        aa1: 'auto auto 1fr',
      },
    },
  },
  variants: {
    backgroundColor: ['responsive', 'hover', 'focus', 'active'],
  },
  plugins: [
    require('tailwindcss-interaction-variants'),
    plugin(function ({ addUtilities }) {
      const gridAddon = {
        '.align-content-start': {
          alignContent: 'start',
        },
        '.align-content-center': {
          alignContent: 'center',
        },
        '.align-content-end': {
          alignContent: 'end',
        },
        '.align-content-stretch': {
          alignContent: 'stretch',
        },
        '.justify-items-start': {
          justifyItems: 'start',
        },
        '.justify-items-center': {
          justifyItems: 'center',
        },
        '.justify-items-end': {
          justifyItems: 'end',
        },
        '.justify-items-between': {
          justifyItems: 'space-between',
        },
        '.justify-items-around': {
          justifyItems: 'space-around',
        },
        '.justify-self-start': {
          justifySelf: 'start',
        },
        '.justify-self-center': {
          justifySelf: 'center',
        },
        '.justify-self-end': {
          justifySelf: 'end',
        },
        '.justify-self-between': {
          justifySelf: 'space-between',
        },
        '.justify-self-around': {
          justifySelf: 'space-around',
        },
      };

      addUtilities(gridAddon, {
        variants: ['responsive'],
      });
    }),
    plugin(function ({ addUtilities }) {
      const positionedAddon = {
        '.top-subnav': {
          top: 'calc(4rem + 1px)',
        },
        '.top-1': {
          top: '0.25rem',
        },
        '.right-1': {
          right: '0.25rem',
        },
        '.bottom-1': {
          bottom: '0.25rem',
        },
        '.left-1': {
          left: '0.25rem',
        },
        '.top-2': {
          top: '0.5rem',
        },
        '.right-2': {
          right: '0.5rem',
        },
        '.bottom-2': {
          bottom: '0.5rem',
        },
        '.left-2': {
          left: '0.5rem',
        },
        '.top-3': {
          top: '0.75rem',
        },
        '.right-3': {
          right: '0.75rem',
        },
        '.bottom-3': {
          bottom: '0.75rem',
        },
        '.left-3': {
          left: '0.75rem',
        },
        '.top-4': {
          top: '1rem',
        },
        '.right-4': {
          right: '1rem',
        },
        '.bottom-4': {
          bottom: '1rem',
        },
        '.left-4': {
          left: '1rem',
        },
      };

      addUtilities(positionedAddon, {
        variants: ['responsive'],
      });
    }),
    plugin(function ({ addUtilities }) {
      const translateAddon = {
        '.translate-3d': {
          transform: 'translate3d(0, 0, 0)',
        },
      };

      addUtilities(translateAddon);
    }),
  ],
};
